@@ -1,7 +1,7 @@
 # cpf.py - functions for handling CPF numbers
 # coding: utf-8
 #
-# Copyright (C) 2011 Arthur de Jong
+# Copyright (C) 2011, 2012 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling CPF (Cadastro de Pessoas Físicas) numbers, the
-Brazillian national identification number.
+"""CPF (Cadastro de Pessoas Físicas, Brazillian national identifier).
 
 >>> is_valid('390.533.447-05')
 True
@@ -31,11 +30,13 @@ False
 '231.002.999-00'
 """
 
+from stdnum.util import clean
+
 
 def compact(number):
     """Convert the number to the minimal representation. This strips the
     number of any valid separators and removes surrounding whitespace."""
-    return number.replace(' ', '').replace('-', '').replace('.', '').strip()
+    return clean(number, ' -.').strip()
 
 
 def _calc_check_digits(number):
