@@ -1,7 +1,7 @@
 # imei.py - functions for handling International Mobile Equipment Identity
 #           (IMEI) numbers
 #
-# Copyright (C) 2010, 2011 Arthur de Jong
+# Copyright (C) 2010, 2011, 2012 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling IMEI (International Mobile Equipment Identity)
-numbers, used to identify mobile phones.
+"""IMEI (International Mobile Equipment Identity).
+
+The  IMEI is used to identify mobile phones. The IMEI may optionally
+include a check digit which is validated using the Luhn algorithm.
 
 >>> is_valid('35686800-004141-20')
 True
@@ -37,11 +39,13 @@ False
 ('35686800', '004141', '')
 """
 
+from stdnum.util import clean
+
 
 def compact(number):
     """Convert the IMEI number to the minimal representation. This strips the
     number of any valid separators and removes surrounding whitespace."""
-    return number.replace(' ', '').replace('-', '').strip().upper()
+    return clean(number, ' -').strip().upper()
 
 
 def imei_type(number):
