@@ -1,6 +1,6 @@
 # isbn.py - functions for handling ISBNs
 #
-# Copyright (C) 2010, 2011 Arthur de Jong
+# Copyright (C) 2010, 2011, 2012 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,9 +17,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling ISBNs (International Standard Book Number). This
-module handles both numbers in ISBN-10 (10-digit) and ISBN-13 (13-digit)
-format.
+"""ISBN (International Standard Book Number).
+
+The ISBN is the International Standard Book Number, used to identify
+publications. This module supports both numbers in ISBN-10 (10-digit) and
+ISBN-13 (13-digit) format.
 
 >>> is_valid('978-9024538270')
 True
@@ -42,6 +44,7 @@ False
 """
 
 from stdnum import ean
+from stdnum.util import clean
 
 
 def compact(number, convert=False):
@@ -49,7 +52,7 @@ def compact(number, convert=False):
     of any valid ISBN separators and removes surrounding whitespace. If the
     covert parameter is True the number is also converted to ISBN-13
     format."""
-    number = number.replace(' ', '').replace('-', '').strip().upper()
+    number = clean(number, ' -').strip().upper()
     if len(number) == 9:
         number = '0' + number
     if convert:
@@ -84,8 +87,6 @@ def isbn_type(number):
         if ean.calc_check_digit(number[:-1]) != number[-1]:
             return None
         return 'ISBN13'
-    else:
-        return None
 
 
 def is_valid(number):
@@ -114,7 +115,7 @@ def to_isbn13(number):
 
 
 def to_isbn10(number):
-    """Convert the number to ISBN-13 format."""
+    """Convert the number to ISBN-10 format."""
     number = number.strip()
     min_number = compact(number)
     if len(min_number) == 10:
