@@ -1,6 +1,6 @@
-# mod_97_10.py - functions for performing the ISO 7064 Mod 97, 10 algorithm
+# mod_11_10.py - functions for performing the ISO 7064 Mod 11, 10 algorithm
 #
-# Copyright (C) 2010, 2011 Arthur de Jong
+# Copyright (C) 2010, 2011, 2012 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,39 +17,41 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the check digits of a number
-using the ISO 7064 Mod 97, 10 algorithm.
+"""The ISO 7064 Mod 11, 10 algorithm.
 
-Validation can be done with is_valid(). A valid number can be made by
-calculating the check digits and appending them.
+The Mod 11, 10 algorithm uses a number of calculations modulo 11 and 10 to
+determine a checksum.
 
+For a module that can do generic Mod x+1, x calculations see the
+:mod:`stdnum.iso7064.mod_37_36` module.
 
->>> calc_check_digits('99991234567890121414')
-'90'
->>> is_valid('9999123456789012141490')
+>>> calc_check_digit('79462')
+'3'
+>>> is_valid('794623')
 True
->>> calc_check_digits('4354111611551114')
-'31'
->>> is_valid('08686001256515001121751')
+>>> calc_check_digit('00200667308')
+'5'
+>>> is_valid('002006673085')
 True
->>> calc_check_digits('22181321402534321446701611')
-'35'
 """
 
 
 def checksum(number):
-    """Calculate the checksum."""
-    return int(number) % 97
+    """Calculate the checksum. A valid number should have a checksum of 1."""
+    check = 5
+    for n in number:
+        check = (((check or 10) * 2) % 11 + int(n)) % 10
+    return check
 
 
-def calc_check_digits(number):
+def calc_check_digit(number):
     """With the provided number, calculate the extra digit that should be
     appended to make it a valid number."""
-    return '%02d' % ((98 - 100 * checksum(number)) % 97)
+    return str((1 - ((checksum(number) or 10) * 2) % 11) % 10)
 
 
 def is_valid(number):
-    """Determines whether the number has a valid checksum."""
+    """Checks whether the check digit is valid."""
     try:
         return bool(number) and checksum(number) == 1
     except:
