@@ -1,6 +1,6 @@
 # luhn.py - functions for performing the Luhn and Luhn mod N algorithms
 #
-# Copyright (C) 2010, 2011 Arthur de Jong
+# Copyright (C) 2010, 2011, 2012 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,12 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for calculation and verifying the checksum of a number
-using the Luhn algorithm.
+"""The Luhn and Luhn mod N algorithms.
 
-Validation can be done with is_valid() which validates that the
-calculated checksum is 0. A valid number can be made by calculating
-the check digit and appending it.
+The Luhn algorithm is used to detect most accidental errors in various
+identification numbers.
 
 >>> is_valid('7894')
 False
@@ -40,7 +38,6 @@ The default alphabet is '0123456789'.
 False
 >>> checksum('1234', alphabet='0123456789abcdef')
 14
-
 """
 
 
