@@ -1,6 +1,6 @@
 # bsn.py - functions for handling BSNs
 #
-# Copyright (C) 2010, 2011 Arthur de Jong
+# Copyright (C) 2010, 2011, 2012 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling BSNs (Burgerservicenummer), the
-Dutch national identification number.
+"""BSN (Burgerservicenummer, the Dutch national identification number).
+
+The BSN is a number with up to 9 digits (the leading 0's are commonly left
+out) which is used as the Dutch national identification number.
 
 >>> is_valid('111222333')
 True
@@ -30,18 +32,22 @@ False
 '1112.22.333'
 """
 
+from stdnum.util import clean
+
 
 def compact(number):
     """Convert the number to the minimal representation. This strips the
     number of any valid separators and removes surrounding whitespace."""
-    number = number.replace(' ', '').replace('-', '').replace('.', '').strip()
+    number = clean(number, ' -.').strip()
     # pad with leading zeroes
     return (9 - len(number)) * '0' + number
 
 
-def _calc_checksum(number):
-    """Calculate the checksum over the number."""
-    return sum((9 - i) * int(number[i]) for i in range(8)) - int(number[8])
+def checksum(number):
+    """Calculate the checksum over the number. A valid number should have
+    a check digit of 0."""
+    return (sum((9 - i) * int(n) for i, n in enumerate(number[:-1])) -
+            int(number[-1])) % 11
 
 
 def is_valid(number):
@@ -51,10 +57,8 @@ def is_valid(number):
         number = compact(number)
     except:
         return False
-    return len(number) == 9 and \
-           number.isdigit() and \
-           int(number) > 0 and \
-           _calc_checksum(number) % 11 == 0
+    return len(number) == 9 and number.isdigit() and \
+           int(number) > 0 and checksum(number) == 0
 
 
 def format(number):
