@@ -18,13 +18,15 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""This module contains functions for reading and querying a database for
-storing numbers that use a hierarchical format (e.g. ISBN, IBAN, phone
+"""Query structured number format files with number properties.
+
+This module contains functions for reading and querying a database that
+stores numbers that use a hierarchical format (e.g. ISBN, IBAN, phone
 numbers, etc).
 
 To read a database from a file:
 
->>> dbfile = read(open('test.dat', 'r'))
+>>> dbfile = read(open('numdb-test.dat', 'r'))
 
 To split a number:
 
@@ -132,7 +134,7 @@ def _parse(fp):
     for line in fp:
         # ignore comments
         if line[0] == '#' or line.strip() == '':
-            continue
+            continue  # pragma: no cover (optimisation takes it out)
         # any other line should parse
         match = _line_re.search(line)
         indent = len(match.group('indent'))
