@@ -1,6 +1,6 @@
 # ssn.py - functions for handling SSNs
 #
-# Copyright (C) 2011 Arthur de Jong
+# Copyright (C) 2011, 2012 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,8 +17,10 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Module for handling U.S. Social Security Numbers (SSN), the number
-to identify individuals for taxation purposes.
+"""SSN (U.S. Social Security Number).
+
+The Social Security Number is used to identify individuals for taxation
+purposes.
 
 >>> is_valid('111-22-3333')
 True
@@ -34,6 +36,9 @@ False
 
 import re
 
+from stdnum.util import clean
+
+
 # regular expression for matching SSN
 _ssn_re = re.compile('^(?P<area>[0-9]{3})-?(?P<group>[0-9]{2})-?(?P<serial>[0-9]{4})$')
 
@@ -44,7 +49,7 @@ _ssn_blacklist = set(('078-05-1120', '457-55-5462', '219-09-9999'))
 def compact(number):
     """Convert the number to the minimal representation. This strips the
     number of any valid separators and removes surrounding whitespace."""
-    return number.replace('-', '').strip()
+    return clean(number, '-').strip()
 
 
 def is_valid(number):
